"""
This module contains callback lists


--------------------

This script shows the most simple example of adding a handler.

```../examples/bpy.app.handlers.0.py```


--------------------

By default handlers are freed when loading new files, in some cases you may
want the handler stay running across multiple files (when the handler is
part of an add-on for example).

For this the bpy.app.handlers.persistent decorator needs to be used.

```../examples/bpy.app.handlers.1.py```


--------------------

Altering data from handlers should be done carefully. While rendering the
frame_change_pre

 and frame_change_post

 handlers are called from one
thread and the viewport updates from a different thread. If the handler changes
data that is accessed by the viewport, this can cause a crash of Blender. In
such cases, lock the interface (Render → Lock Interface or
bpy.types.RenderSettings.use_lock_interface) before starting a render.

Below is an example of a mesh that is altered from a handler:

```../examples/bpy.app.handlers.2.py```

"""

import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.types

animation_playback_post: list[
    collections.abc.Callable[[bpy.types.Scene, bpy.types.Depsgraph], None]
    | collections.abc.Callable[[bpy.types.Scene], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on ending animation playback. Accepts one or two arguments: The scene data-block, and optionally the dependency graph being updated
"""

animation_playback_pre: list[
    collections.abc.Callable[[bpy.types.Scene, bpy.types.Depsgraph], None]
    | collections.abc.Callable[[bpy.types.Scene], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on starting animation playback. Accepts one or two arguments: The scene data-block, and optionally the dependency graph being updated
"""

annotation_post: list[
    collections.abc.Callable[[bpy.types.GreasePencil, bpy.types.Depsgraph], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on drawing an annotation (after). Accepts two arguments: the annotation data-block and dependency graph
"""

annotation_pre: list[
    collections.abc.Callable[[bpy.types.GreasePencil, bpy.types.Depsgraph], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on drawing an annotation (before). Accepts two arguments: the annotation data-block and dependency graph
"""

blend_import_post: list[
    collections.abc.Callable[[bpy.types.BlendImportContext], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on linking or appending data (after). Accepts one argument: a BlendImportContext
"""

blend_import_pre: list[
    collections.abc.Callable[[bpy.types.BlendImportContext], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on linking or appending data (before). Accepts one argument: a BlendImportContext
"""

composite_cancel: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on a compositing background job (cancel). Accepts one argument: the scene data-block
"""

composite_post: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on a compositing background job (after). Accepts one argument: the scene data-block
"""

composite_pre: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on a compositing background job (before). Accepts one argument: the scene data-block
"""

depsgraph_update_post: list[
    collections.abc.Callable[[bpy.types.Scene, bpy.types.Depsgraph], None]
]
""" on depsgraph update (post). Accepts one or two arguments: The scene data-block, and optionally the dependency graph being updated
"""

depsgraph_update_pre: list[collections.abc.Callable[[bpy.types.Scene, None], None]]
""" on depsgraph update (pre). Accepts one or two arguments: The scene data-block, and optionally the dependency graph being updated
"""

exit_pre: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[bool, None]
]
""" just before Blender shuts down, while all data is still valid. Accepts one boolean argument. True indicates either that a user has been using Blender and exited, or that Blender is exiting in a circumstance that should be treated as if that were the case. False indicates that Blender is running in background mode, or is exiting due to failed command line arguments, etc.
"""

frame_change_post: list[
    collections.abc.Callable[[bpy.types.Scene, bpy.types.Depsgraph], None]
    | collections.abc.Callable[[bpy.types.Scene], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" Called after frame change for playback and rendering, after the data has been evaluated for the new frame. Accepts one or two arguments: The scene data-block, and optionally the dependency graph being updated
"""

frame_change_pre: list[
    collections.abc.Callable[[bpy.types.Scene, bpy.types.Depsgraph], None]
    | collections.abc.Callable[[bpy.types.Scene], None]
] | list[collections.abc.Callable[[bpy.types.Scene], None]]
""" Called when a frame change is triggered for playback and rendering, before any data is evaluated for the new frame. This makes it possible to change data and relations (for example swap an object to another mesh) for the new frame. Note that this handler is not to be used as before the frame changes event. The dependency graph is not available in this handler, as data and relations may have been altered and the dependency graph has not yet been updated for that. Accepts one or two arguments: The scene data-block, and optionally the dependency graph being updated
"""

load_factory_preferences_post: list[collections.abc.Callable[None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" on loading factory preferences (after)
"""

load_factory_startup_post: list[collections.abc.Callable[None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" on loading factory startup (after)
"""

load_post: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[str, None]
]
""" on loading a new blend file (after). Accepts one argument: the file being loaded, an empty string for the startup-file.
"""

load_post_fail: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[str, None]
]
""" on failure to load a new blend file (after). Accepts one argument: the file being loaded, an empty string for the startup-file.
"""

load_pre: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[str, None]
]
""" on loading a new blend file (before). Accepts one argument: the file being loaded, an empty string for the startup-file.
"""

object_bake_cancel: list[collections.abc.Callable[[bpy.types.Object], None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" on canceling a bake job; will be called in the main thread. Accepts one argument: the object data-block being baked
"""

object_bake_complete: list[collections.abc.Callable[[bpy.types.Object], None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" on completing a bake job; will be called in the main thread. Accepts one argument: the object data-block being baked
"""

object_bake_pre: list[collections.abc.Callable[[bpy.types.Object], None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" before starting a bake job. Accepts one argument: the object data-block being baked
"""

persistent: typing.Any
""" Function decorator for callback functions not to be removed when loading new files
"""

redo_post: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on loading a redo step (after). Accepts one argument: the scene data-block
"""

redo_pre: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on loading a redo step (before). Accepts one argument: the scene data-block
"""

render_cancel: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on canceling a render job. Accepts one argument: the scene data-block being rendered
"""

render_complete: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on completion of render job. Accepts one argument: the scene data-block being rendered
"""

render_init: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on initialization of a render job. Accepts one argument: the scene data-block being rendered
"""

render_post: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on render (after). Accepts one argument: the scene data-block being rendered
"""

render_pre: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on render (before). Accepts one argument: the scene data-block being rendered
"""

render_stats: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[str, None]
]
""" on printing render statistics. Accepts one argument: the render stats (render/saving time plus in background mode frame/used [peak] memory).
"""

render_write: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on writing a render frame (directly after the frame is written). Accepts one argument: the scene data-block being rendered
"""

save_post: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[str, None]
]
""" on saving a blend file (after). Accepts one argument: the file being saved, an empty string for the startup-file.
"""

save_post_fail: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[str, None]
]
""" on failure to save a blend file (after). Accepts one argument: the file being saved, an empty string for the startup-file.
"""

save_pre: list[collections.abc.Callable[[bpy.types.Scene], None]] | list[
    collections.abc.Callable[str, None]
]
""" on saving a blend file (before). Accepts one argument: the file being saved, an empty string for the startup-file.
"""

translation_update_post: list[collections.abc.Callable[None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" on translation settings update
"""

undo_post: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on loading an undo step (after). Accepts one argument: the scene data-block
"""

undo_pre: list[collections.abc.Callable[[bpy.types.Scene], None]]
""" on loading an undo step (before). Accepts one argument: the scene data-block
"""

version_update: list[collections.abc.Callable[None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" on ending the versioning code
"""

xr_session_start_pre: list[collections.abc.Callable[None]] | list[
    collections.abc.Callable[[bpy.types.Scene], None]
]
""" on starting an xr session (before)
"""



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def edges_from_elem(ele) -> None: ...
def elems_depth_measure(ele_dst, ele_src, other_edges_over_cb) -> None:
    """Returns·ele_dst vert depths from ele_src, aligned with ele_dst verts."""

def elems_depth_search(
    ele_init, depths, other_edges_over_cb, results_init=None
) -> None:
    """List of depths -> List of elems that match those depths."""

def find_next(ele_dst, ele_src) -> None: ...
def other_edges_over_edge(e) -> None: ...
def other_edges_over_face(e) -> None: ...
def select_next(bm, report) -> None: ...
def select_prev(bm, report) -> None: ...
def verts_from_elem(ele) -> None: ...



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.types

def addon_keymap_register(
    keymap_data: list[tuple[str, dict[str, typing.Any], dict[str, typing.Any]]],
) -> None:
    """Register a set of keymaps for addons using a list of keymaps.See blender_default.py for examples of the format this takes.

    :param keymap_data: A list of keymap definitions to register.
    """

def addon_keymap_unregister(
    keymap_data: list[tuple[str, dict[str, typing.Any], dict[str, typing.Any]]],
) -> None:
    """Unregister a set of keymaps for addons.

    :param keymap_data: A list of keymap definitions to unregister.
    """

def keyconfig_test(kc: bpy.types.KeyConfig) -> bool:
    """Test a key configuration for duplicate key-map item assignments.

    :param kc: The key configuration to test.
    :return: True if any duplicates were found.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import _bpy_types
import bl_ui.space_properties
import bpy.types
import rna_prop_ui

class SceneButtonsPanel:
    bl_context: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

class SCENE_PT_animation(
    rna_prop_ui.PropertyPanel,
    SceneButtonsPanel,
    bl_ui.space_properties.PropertiesAnimationMixin,
    _bpy_types.Panel,
):
    """Mix-in class for Animation panels.This class can be used to show a generic Animation panel for IDs shown in
    the properties editor. Specific ID types need specific subclasses.For an example, see DATA_PT_camera_animation in properties_data_camera.py
    """

    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_order: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_audio(SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_context_scene(SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_custom_props(
    rna_prop_ui.PropertyPanel, SceneButtonsPanel, _bpy_types.Panel
):
    """The subclass should have its own poll function
    and the variable _context_path MUST be set.
    """

    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_order: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

class SCENE_PT_eevee_light_probes(SceneButtonsPanel, _bpy_types.Panel):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class SCENE_PT_keyframing_settings(
    SceneKeyingSetsPanel, SceneButtonsPanel, _bpy_types.Panel
):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class SCENE_PT_keying_set_paths(
    SceneKeyingSetsPanel, SceneButtonsPanel, _bpy_types.Panel
):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class SCENE_PT_keying_sets(SceneKeyingSetsPanel, SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_physics(SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    def draw_header(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_rigid_body_cache(RigidBodySubPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_rigid_body_field_weights(RigidBodySubPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_rigid_body_world(SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    def draw_header(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_rigid_body_world_settings(RigidBodySubPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_scene(SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_simulation(SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_PT_unit(SceneButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class SCENE_UL_keying_set_paths(_bpy_types.UIList):
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

class SceneKeyingSetsPanel:
    @staticmethod
    def draw_keyframing_settings(context, layout, ks, ksp) -> None:
        """

        :param context:
        :param layout:
        :param ks:
        :param ksp:
        """

class RigidBodySubPanel(SceneButtonsPanel):
    bl_context: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

class AssetDownloader:
    OnAssetDoneCallback: typing.Any
    OnDoneCallback: typing.Any
    OnUpdateCallback: typing.Any
    error_message: typing.Any
    local_path: typing.Any
    remote_url: typing.Any
    status: typing.Any

    def already_downloaded(self, http_req_descr, local_file) -> None:
        """

        :param http_req_descr:
        :param local_file:
        """

    def download_asset_file(self, asset_url, save_to) -> None:
        """Download an asset or preview file to a local file.

        :param asset_url:
        :param save_to:
        """

    def download_error(self, http_req_descr, local_file, error) -> None:
        """

        :param http_req_descr:
        :param local_file:
        :param error:
        """

    def download_finished(self, http_req_descr, local_file) -> None:
        """

        :param http_req_descr:
        :param local_file:
        """

    def download_progress(
        self, http_req_descr, content_length_bytes, downloaded_bytes
    ) -> None:
        """

        :param http_req_descr:
        :param content_length_bytes:
        :param downloaded_bytes:
        """

    def download_starts(self, http_req_descr) -> None:
        """

        :param http_req_descr:
        """

    def on_timer_event(self) -> None: ...
    def report(self, level, message) -> None:
        """

        :param level:
        :param message:
        """

    def shutdown(self, status) -> None:
        """Stop the background downloader, update the status and call the done callback.

        :param status:
        """

    def start(self) -> None:
        """Start the background process."""

class DownloadStatus:
    """Create a collection of name/value pairs.Example enumeration:Access them by:Enumerations can be iterated over, and know how many members they have:Methods can be added to enumerations, and members can have their own
    attributes -- see the documentation for details.
    """

    DOWNLOADING: typing.Any
    FAILED: typing.Any
    FINISHED: typing.Any
    IDLE: typing.Any
    name: typing.Any
    value: typing.Any

def download_asset_file(
    asset_library_url, asset_library_local_path, asset_url, asset_hash, save_to
) -> None:
    """Download an asset file to a file on disk.

        :param asset_library_url: Root URL of the remote asset library. Used as an
    identifier of this library (to create a downloader per library), as well
    as for resolving relative URLs.
        :param asset_library_local_path: Root path of the local asset cache. Used to
    resolve relative save_to paths, but also to find the HTTP metadata
    cache for this asset library (for conditional downloads).
        :param asset_url: the URL to download. Can be absolute or relative to the
    asset library URL. If it is an empty string, the save_to path is used
    as the URL.
        :param asset_hash: the hash of the asset file, will be appended to the URL.
        :param save_to: the path on disk where to download to. While the download is
    pending, ".part" will be appended to the filename. When the download
    finishes successfully, it is renamed to the final path.
    """

def download_preview(
    asset_library_url, asset_library_local_path, preview_url, preview_hash, dst_filepath
) -> None:
    """Download an asset preview to a file on disk.

        :param asset_library_url: Root URL of the remote asset library. Used as an
    identifier of this library (to create a downloader per library), as well
    as for resolving relative URLs.
        :param asset_library_local_path: Root path of the local asset cache. Used to
    resolve relative save_to paths, but also to find the HTTP metadata
    cache for this asset library (for conditional downloads).
        :param preview_url: the URL to download. Can be absolute or relative.
        :param preview_hash: the hash of the thumbnail, will be appended to the URL.
        :param dst_filepath: the path on disk where to download to. While the
    download is pending, ".part" will be appended to the filename. When the
    download finishes successfully, it is renamed to the final path.
    """

def downloader_status(asset_library_url) -> None:
    """Returns the asset downloader status.Raises a KeyError if there never was a downloader for this URL."""



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def change_frame(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    frame: float | None = 0.0,
    snap: bool | None = False,
    seq_solo_preview: bool | None = False,
    pass_through_on_strip_handles: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Interactively change the current frame number

    :param frame: Frame, (in [-1.04857e+06, 1.04857e+06], optional)
    :param snap: Snap, (optional)
    :param seq_solo_preview: Strip Preview, (optional)
    :param pass_through_on_strip_handles: Pass Through on Strip Handles, Allow another operator to operate on strip handles (optional)
    :return: Result of the operator call.
    """

def channel_select_keys(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all keyframes of channel under mouse

    :param extend: Extend, Extend selection (optional)
    :return: Result of the operator call.
    """

def channel_view_pick(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    include_handles: bool | None = True,
    use_preview_range: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reset viewable area to show the channel under the cursor

    :param include_handles: Include Handles, Include handles of keyframes when calculating extents (optional)
    :param use_preview_range: Use Preview Range, Ignore frames outside of the preview range (optional)
    :return: Result of the operator call.
    """

def channels_bake(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    use_scene_range: bool | None = True,
    range: collections.abc.Sequence[int] | None = (0, 0),
    step: float | None = 1.0,
    remove_outside_range: bool | None = False,
    interpolation_type: typing.Literal["BEZIER", "LIN", "CONST"] | None = "BEZIER",
    bake_modifiers: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create keyframes following the current shape of F-Curves of selected channels

        :param use_scene_range: Use Scene Range, If enabled, the scene start and end frame will be used to determine the bake range (optional)
        :param range: Frame Range, The custom range in which to create new keys. Only used when not using the scene range (array of 2 items, in [-inf, inf], optional)
        :param step: Frame Step, At which interval to add keys (in [0.01, inf], optional)
        :param remove_outside_range: Remove Outside Range, Removes keys outside the given range, leaving only the newly baked (optional)
        :param interpolation_type: Interpolation Type, Choose the interpolation type with which new keys will be added (optional)

    BEZIER
    Bézier -- New keys will be Bézier.

    LIN
    Linear -- New keys will be linear.

    CONST
    Constant -- New keys will be constant.
        :param bake_modifiers: Bake Modifiers, Bake Modifiers into keyframes and delete them after (optional)
        :return: Result of the operator call.
    """

def channels_clean_empty(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete all empty animation data containers from visible data-blocks

    :return: Result of the operator call.
    """

def channels_click(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
    extend_range: bool | None = False,
    children_only: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Handle mouse clicks over animation channels

    :param extend: Extend Select, (optional)
    :param extend_range: Extend Range, Selection of active channel to clicked channel (optional)
    :param children_only: Select Children Only, (optional)
    :return: Result of the operator call.
    """

def channels_collapse(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Collapse (close) all selected expandable animation channels

    :param all: All, Collapse all channels (not just selected ones) (optional)
    :return: Result of the operator call.
    """

def channels_delete(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete all selected animation channels

    :return: Result of the operator call.
    """

def channels_editable_toggle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mode: typing.Literal["TOGGLE", "DISABLE", "ENABLE", "INVERT"] | None = "TOGGLE",
    type: typing.Literal["PROTECT", "MUTE"] | None = "PROTECT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Toggle editability of selected channels

    :param mode: Mode, (optional)
    :param type: Type, (optional)
    :return: Result of the operator call.
    """

def channels_expand(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Expand (open) all selected expandable animation channels

    :param all: All, Expand all channels (not just selected ones) (optional)
    :return: Result of the operator call.
    """

def channels_fcurves_enable(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Clear disabled tag from all F-Curves to get broken F-Curves working again

    :return: Result of the operator call.
    """

def channels_group(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    name: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add selected F-Curves to a new group

    :param name: Name, Name of newly created group (optional, never None)
    :return: Result of the operator call.
    """

def channels_move(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    direction: typing.Literal["TOP", "UP", "DOWN", "BOTTOM"] | None = "DOWN",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Rearrange selected animation channels

    :param direction: Direction, (optional)
    :return: Result of the operator call.
    """

def channels_rename(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Rename animation channel under mouse

    :return: Result of the operator call.
    """

def channels_select_all(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    action: typing.Literal["TOGGLE", "SELECT", "DESELECT", "INVERT"] | None = "TOGGLE",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Toggle selection of all animation channels

        :param action: Action, Selection action to execute (optional)

    TOGGLE
    Toggle -- Toggle selection for all elements.

    SELECT
    Select -- Select all elements.

    DESELECT
    Deselect -- Deselect all elements.

    INVERT
    Invert -- Invert selection of all elements.
        :return: Result of the operator call.
    """

def channels_select_box(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    xmin: int | None = 0,
    xmax: int | None = 0,
    ymin: int | None = 0,
    ymax: int | None = 0,
    wait_for_input: bool | None = True,
    deselect: bool | None = False,
    extend: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all animation channels within the specified region

    :param xmin: X Min, (in [-inf, inf], optional)
    :param xmax: X Max, (in [-inf, inf], optional)
    :param ymin: Y Min, (in [-inf, inf], optional)
    :param ymax: Y Max, (in [-inf, inf], optional)
    :param wait_for_input: Wait for Input, (optional)
    :param deselect: Deselect, Deselect rather than select items (optional)
    :param extend: Extend, Extend selection instead of deselecting everything first (optional)
    :return: Result of the operator call.
    """

def channels_select_filter(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Start entering text which filters the set of channels shown to only include those with matching names

    :return: Result of the operator call.
    """

def channels_setting_disable(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mode: typing.Literal["TOGGLE", "DISABLE", "ENABLE", "INVERT"] | None = "DISABLE",
    type: typing.Literal["PROTECT", "MUTE"] | None = "PROTECT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Disable specified setting on all selected animation channels

    :param mode: Mode, (optional)
    :param type: Type, (optional)
    :return: Result of the operator call.
    """

def channels_setting_enable(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mode: typing.Literal["TOGGLE", "DISABLE", "ENABLE", "INVERT"] | None = "ENABLE",
    type: typing.Literal["PROTECT", "MUTE"] | None = "PROTECT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Enable specified setting on all selected animation channels

    :param mode: Mode, (optional)
    :param type: Type, (optional)
    :return: Result of the operator call.
    """

def channels_setting_toggle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mode: typing.Literal["TOGGLE", "DISABLE", "ENABLE", "INVERT"] | None = "TOGGLE",
    type: typing.Literal["PROTECT", "MUTE"] | None = "PROTECT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Toggle specified setting on all selected animation channels

    :param mode: Mode, (optional)
    :param type: Type, (optional)
    :return: Result of the operator call.
    """

def channels_ungroup(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove selected F-Curves from their current groups

    :return: Result of the operator call.
    """

def channels_view_selected(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    include_handles: bool | None = True,
    use_preview_range: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reset viewable area to show the selected channels

    :param include_handles: Include Handles, Include handles of keyframes when calculating extents (optional)
    :param use_preview_range: Use Preview Range, Ignore frames outside of the preview range (optional)
    :return: Result of the operator call.
    """

def clear_useless_actions(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    only_unused: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Mark actions with no F-Curves for deletion after save and reload of file preserving "action libraries"

    :param only_unused: Only Unused, Only unused (Fake User only) actions get considered (optional)
    :return: Result of the operator call.
    """

def copy_driver_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy the driver for the highlighted button

    :return: Result of the operator call.
    """

def driver_button_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add driver for the property under the cursor

    :return: Result of the operator call.
    """

def driver_button_edit(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Edit the drivers for the connected property represented by the highlighted button

    :return: Result of the operator call.
    """

def driver_button_remove(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove the driver(s) for the connected property(s) represented by the highlighted button

    :param all: All, Delete drivers for all elements of the array (optional)
    :return: Result of the operator call.
    """

def end_frame_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set the current frame as the preview or scene end frame

    :return: Result of the operator call.
    """

def keyframe_clear_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Clear all keyframes on the currently active property

    :param all: All, Clear keyframes from all elements of the array (optional)
    :return: Result of the operator call.
    """

def keyframe_clear_v3d(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    confirm: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove all keyframe animation for selected objects

    :param confirm: Confirm, Prompt for confirmation (optional)
    :return: Result of the operator call.
    """

def keyframe_clear_vse(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    confirm: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove all keyframe animation for selected strips

    :param confirm: Confirm, Prompt for confirmation (optional)
    :return: Result of the operator call.
    """

def keyframe_delete(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["DEFAULT"] | None = "DEFAULT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete keyframes on the current frame for all properties in the specified Keying Set

    :param type: Keying Set, The Keying Set to use (optional)
    :return: Result of the operator call.
    """

def keyframe_delete_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete current keyframe of current UI-active property

    :param all: All, Delete keyframes from all elements of the array (optional)
    :return: Result of the operator call.
    """

def keyframe_delete_by_name(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Alternate access to Delete Keyframe for keymaps to use

    :param type: Keying Set, The Keying Set to use (optional, never None)
    :return: Result of the operator call.
    """

def keyframe_delete_v3d(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    confirm: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove keyframes on current frame for selected objects and bones

    :param confirm: Confirm, Prompt for confirmation (optional)
    :return: Result of the operator call.
    """

def keyframe_delete_vse(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    confirm: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove keyframes on current frame for selected strips

    :param confirm: Confirm, Prompt for confirmation (optional)
    :return: Result of the operator call.
    """

def keyframe_insert(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["DEFAULT"] | None = "DEFAULT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Insert keyframes on the current frame using either the active keying set, or the user preferences if no keying set is active

    :param type: Keying Set, The Keying Set to use (optional)
    :return: Result of the operator call.
    """

def keyframe_insert_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Insert a keyframe for current UI-active property

    :param all: All, Insert a keyframe for all element of the array (optional)
    :return: Result of the operator call.
    """

def keyframe_insert_by_name(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Alternate access to Insert Keyframe for keymaps to use

    :param type: Keying Set, The Keying Set to use (optional, never None)
    :return: Result of the operator call.
    """

def keyframe_insert_menu(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["DEFAULT"] | None = "DEFAULT",
    always_prompt: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Insert Keyframes for specified Keying Set, with menu of available Keying Sets if undefined

    :param type: Keying Set, The Keying Set to use (optional)
    :param always_prompt: Always Show Menu, (optional)
    :return: Result of the operator call.
    """

def keying_set_active_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["DEFAULT"] | None = "DEFAULT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set a new active keying set

    :param type: Keying Set, The Keying Set to use (optional)
    :return: Result of the operator call.
    """

def keying_set_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add a new (empty) keying set to the active Scene

    :return: Result of the operator call.
    """

def keying_set_export(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
    filter_folder: bool | None = True,
    filter_text: bool | None = True,
    filter_python: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Export Keying Set to a Python script

    :param filepath: filepath, (optional, never None)
    :param filter_folder: Filter folders, (optional)
    :param filter_text: Filter text, (optional)
    :param filter_python: Filter Python, (optional)
    :return: Result of the operator call.
    """

def keying_set_path_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add empty path to active keying set

    :return: Result of the operator call.
    """

def keying_set_path_remove(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove active Path from active keying set

    :return: Result of the operator call.
    """

def keying_set_remove(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove the active keying set

    :return: Result of the operator call.
    """

def keyingset_button_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add current UI-active property to current keying set

    :param all: All, Add all elements of the array to a Keying Set (optional)
    :return: Result of the operator call.
    """

def keyingset_button_remove(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove current UI-active property from current keying set

    :return: Result of the operator call.
    """

def merge_animation(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Merge the animation of the selected objects into the action of the active object. Actions are not deleted by this, but might end up with zero users

    :return: Result of the operator call.
    """

def paste_driver_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Paste the driver in the internal clipboard to the highlighted button

    :return: Result of the operator call.
    """

def previewrange_clear(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Clear preview range

    :return: Result of the operator call.
    """

def previewrange_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    xmin: int | None = 0,
    xmax: int | None = 0,
    ymin: int | None = 0,
    ymax: int | None = 0,
    wait_for_input: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Interactively define frame range used for playback

    :param xmin: X Min, (in [-inf, inf], optional)
    :param xmax: X Max, (in [-inf, inf], optional)
    :param ymin: Y Min, (in [-inf, inf], optional)
    :param ymax: Y Max, (in [-inf, inf], optional)
    :param wait_for_input: Wait for Input, (optional)
    :return: Result of the operator call.
    """

def replace_action(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    old_session_uid: int | None = 0,
    new_session_uid: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Swap all users of one action to another one. The normal action slot assignment rules apply. This ignores the NLA and Action Constraints

    :param old_session_uid: Old Action, Old Actions session uid to replace (in [-inf, inf], optional)
    :param new_session_uid: Replacement Action, The replacement Actions session uid to remap all selected Actions users to (in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def replace_action_new(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    old_session_uid: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Swap all users of one action to a new action. This ignores the NLA and Action Constraints

    :param old_session_uid: Old Action, Old Actions session uid to replace (in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def scene_range_frame(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reset the horizontal view to the current scene frame range, taking the preview range into account if it is active

    :return: Result of the operator call.
    """

def separate_slots(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Move all slots of the action on the active object into newly created, separate actions. All users of those slots will be reassigned to the new actions. The current action wont be deleted but will be empty and might end up having zero users

    :return: Result of the operator call.
    """

def slot_channels_move_to_new_action(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Move the selected slots into a newly created action

    :return: Result of the operator call.
    """

def slot_new_for_id(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create a new action slot for this data-block, to hold its animation

    :return: Result of the operator call.
    """

def slot_unassign_from_constraint(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Un-assign the action slot from this constraint

    :return: Result of the operator call.
    """

def slot_unassign_from_id(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Un-assign the action slot, effectively making this data-block non-animated

    :return: Result of the operator call.
    """

def slot_unassign_from_nla_strip(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Un-assign the action slot from this NLA strip, effectively making it non-animated

    :return: Result of the operator call.
    """

def start_frame_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set the current frame as the preview or scene start frame

    :return: Result of the operator call.
    """

def update_animated_transform_constraints(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    use_convert_to_radians: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Update f-curves/drivers affecting Transform constraints (use it with files from 2.70 and earlier)

    :param use_convert_to_radians: Convert to Radians, Convert f-curves/drivers affecting rotations to radians.Warning: Use this only once(optional)
    :return: Result of the operator call.
    """

def version_bone_hide_property(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Moves any F-Curves for the hide property of selected armatures into the action of the object. This will only operate on the first layer and strip of the action

    :return: Result of the operator call.
    """

def view_curve_in_graph_editor(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = False,
    isolate: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Frame the property under the cursor in the Graph Editor

    :param all: Show All, Frame the whole array property instead of only the index under the cursor (optional)
    :param isolate: Isolate, Hides all F-Curves other than the ones being framed (optional)
    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def config_logging(args) -> None:
    """Configures the logging system based on CLI arguments."""

def main(cli_args) -> None:
    """CLI entry point for the asset_listing CLI commands."""



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums
import mathutils

def cyclic_toggle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    direction: typing.Literal["CYCLIC_U", "CYCLIC_V"] | None = "CYCLIC_U",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Make active spline closed/open loop

    :param direction: Direction, Direction to make surface cyclic in (optional)
    :return: Result of the operator call.
    """

def de_select_first(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """(De)select first of visible part of each NURBS

    :return: Result of the operator call.
    """

def de_select_last(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """(De)select last of visible part of each NURBS

    :return: Result of the operator call.
    """

def decimate(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    ratio: float | None = 1.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Simplify selected curves

    :param ratio: Ratio, (in [0, 1], optional)
    :return: Result of the operator call.
    """

def delete(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["VERT", "SEGMENT"] | None = "VERT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete selected control points or segments

    :param type: Type, Which elements to delete (optional)
    :return: Result of the operator call.
    """

def dissolve_verts(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete selected control points, correcting surrounding handles

    :return: Result of the operator call.
    """

def draw(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    error_threshold: float | None = 0.0,
    fit_method: Literal[bpy.stub_internal.rna_enums.CurveFitMethodItems]
    | None = "REFIT",
    corner_angle: float | None = 1.22173,
    use_cyclic: bool | None = True,
    stroke=None,
    wait_for_input: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Draw a freehand spline

    :param error_threshold: Error, Error distance threshold (in object units) (in [0, 10], optional)
    :param fit_method: Fit Method, (optional)
    :param corner_angle: Corner Angle, (in [0, 3.14159], optional)
    :param use_cyclic: Cyclic, (optional)
    :param stroke: Stroke, (optional)
    :param wait_for_input: Wait for Input, (optional)
    :return: Result of the operator call.
    """

def duplicate(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Duplicate selected control points

    :return: Result of the operator call.
    """

def duplicate_move(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    CURVE_OT_duplicate: dict[str, typing.Any] | None = {},
    TRANSFORM_OT_translate: dict[str, typing.Any] | None = {},
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Duplicate curve and move

    :param CURVE_OT_duplicate: Duplicate Curve, Duplicate selected control points (optional, `bpy.ops.curve.duplicate` keyword arguments)
    :param TRANSFORM_OT_translate: Move, Move selected items (optional, `bpy.ops.transform.translate` keyword arguments)
    :return: Result of the operator call.
    """

def extrude(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mode: Literal[bpy.stub_internal.rna_enums.TransformModeTypeItems]
    | None = "TRANSLATION",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Extrude selected control point(s)

    :param mode: Mode, (optional)
    :return: Result of the operator call.
    """

def extrude_move(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    CURVE_OT_extrude: dict[str, typing.Any] | None = {},
    TRANSFORM_OT_translate: dict[str, typing.Any] | None = {},
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Extrude curve and move result

    :param CURVE_OT_extrude: Extrude, Extrude selected control point(s) (optional, `bpy.ops.curve.extrude` keyword arguments)
    :param TRANSFORM_OT_translate: Move, Move selected items (optional, `bpy.ops.transform.translate` keyword arguments)
    :return: Result of the operator call.
    """

def handle_type_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal[
        "AUTOMATIC", "VECTOR", "ALIGNED", "FREE_ALIGN", "TOGGLE_FREE_ALIGN"
    ]
    | None = "AUTOMATIC",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set type of handles for selected control points

    :param type: Type, Spline type (optional)
    :return: Result of the operator call.
    """

def hide(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    unselected: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Hide (un)selected control points

    :param unselected: Unselected, Hide unselected rather than selected (optional)
    :return: Result of the operator call.
    """

def make_segment(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Join two curves by their selected ends

    :return: Result of the operator call.
    """

def match_texture_space(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Match texture space to objects bounding box

    :return: Result of the operator call.
    """

def normals_make_consistent(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    calc_length: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Recalculate the direction of selected handles

    :param calc_length: Length, Recalculate handle length (optional)
    :return: Result of the operator call.
    """

def pen(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
    deselect: bool | None = False,
    toggle: bool | None = False,
    deselect_all: bool | None = False,
    select_passthrough: bool | None = False,
    extrude_point: bool | None = False,
    extrude_handle: typing.Literal["AUTO", "VECTOR"] | None = "VECTOR",
    delete_point: bool | None = False,
    insert_point: bool | None = False,
    move_segment: bool | None = False,
    select_point: bool | None = False,
    move_point: bool | None = False,
    close_spline: bool | None = True,
    close_spline_method: typing.Literal["OFF", "ON_PRESS", "ON_CLICK"] | None = "OFF",
    toggle_vector: bool | None = False,
    cycle_handle_type: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Construct and edit splines

        :param extend: Extend, Extend selection instead of deselecting everything first (optional)
        :param deselect: Deselect, Remove from selection (optional)
        :param toggle: Toggle Selection, Toggle the selection (optional)
        :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor (optional)
        :param select_passthrough: Only Select Unselected, Ignore the select action when the element is already selected (optional)
        :param extrude_point: Extrude Point, Add a point connected to the last selected point (optional)
        :param extrude_handle: Extrude Handle Type, Type of the extruded handle (optional)
        :param delete_point: Delete Point, Delete an existing point (optional)
        :param insert_point: Insert Point, Insert Point into a curve segment (optional)
        :param move_segment: Move Segment, Move an existing curve segment (optional)
        :param select_point: Select Point, Select a point or its handles (optional)
        :param move_point: Move Point, Move a point or its handles (optional)
        :param close_spline: Close Spline, Make a spline cyclic by clicking endpoints (optional)
        :param close_spline_method: Close Spline Method, The condition for close spline to activate (optional)

    OFF
    None.

    ON_PRESS
    On Press -- Move handles after closing the spline.

    ON_CLICK
    On Click -- Spline closes on release if not dragged.
        :param toggle_vector: Toggle Vector, Toggle between Vector and Auto handles (optional)
        :param cycle_handle_type: Cycle Handle Type, Cycle between all four handle types (optional)
        :return: Result of the operator call.
    """

def primitive_bezier_circle_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    radius: float | None = 1.0,
    enter_editmode: bool | None = False,
    align: typing.Literal["WORLD", "VIEW", "CURSOR"] | None = "WORLD",
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (
        0.0,
        0.0,
        0.0,
    ),
    rotation: collections.abc.Sequence[float] | mathutils.Euler | None = (
        0.0,
        0.0,
        0.0,
    ),
    scale: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Construct a Bézier Circle

        :param radius: Radius, (in [0, inf], optional)
        :param enter_editmode: Enter Edit Mode, Enter edit mode when adding this object (optional)
        :param align: Align, The alignment of the new object (optional)

    WORLD
    World -- Align the new object to the world.

    VIEW
    View -- Align the new object to the view.

    CURSOR
    3D Cursor -- Use the 3D cursor orientation for the new object.
        :param location: Location, Location for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param rotation: Rotation, Rotation for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param scale: Scale, Scale for the newly added object (array of 3 items, in [-inf, inf], optional)
        :return: Result of the operator call.
    """

def primitive_bezier_curve_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    radius: float | None = 1.0,
    enter_editmode: bool | None = False,
    align: typing.Literal["WORLD", "VIEW", "CURSOR"] | None = "WORLD",
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (
        0.0,
        0.0,
        0.0,
    ),
    rotation: collections.abc.Sequence[float] | mathutils.Euler | None = (
        0.0,
        0.0,
        0.0,
    ),
    scale: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Construct a Bézier Curve

        :param radius: Radius, (in [0, inf], optional)
        :param enter_editmode: Enter Edit Mode, Enter edit mode when adding this object (optional)
        :param align: Align, The alignment of the new object (optional)

    WORLD
    World -- Align the new object to the world.

    VIEW
    View -- Align the new object to the view.

    CURSOR
    3D Cursor -- Use the 3D cursor orientation for the new object.
        :param location: Location, Location for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param rotation: Rotation, Rotation for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param scale: Scale, Scale for the newly added object (array of 3 items, in [-inf, inf], optional)
        :return: Result of the operator call.
    """

def primitive_nurbs_circle_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    radius: float | None = 1.0,
    enter_editmode: bool | None = False,
    align: typing.Literal["WORLD", "VIEW", "CURSOR"] | None = "WORLD",
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (
        0.0,
        0.0,
        0.0,
    ),
    rotation: collections.abc.Sequence[float] | mathutils.Euler | None = (
        0.0,
        0.0,
        0.0,
    ),
    scale: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Construct a Nurbs Circle

        :param radius: Radius, (in [0, inf], optional)
        :param enter_editmode: Enter Edit Mode, Enter edit mode when adding this object (optional)
        :param align: Align, The alignment of the new object (optional)

    WORLD
    World -- Align the new object to the world.

    VIEW
    View -- Align the new object to the view.

    CURSOR
    3D Cursor -- Use the 3D cursor orientation for the new object.
        :param location: Location, Location for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param rotation: Rotation, Rotation for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param scale: Scale, Scale for the newly added object (array of 3 items, in [-inf, inf], optional)
        :return: Result of the operator call.
    """

def primitive_nurbs_curve_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    radius: float | None = 1.0,
    enter_editmode: bool | None = False,
    align: typing.Literal["WORLD", "VIEW", "CURSOR"] | None = "WORLD",
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (
        0.0,
        0.0,
        0.0,
    ),
    rotation: collections.abc.Sequence[float] | mathutils.Euler | None = (
        0.0,
        0.0,
        0.0,
    ),
    scale: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Construct a Nurbs Curve

        :param radius: Radius, (in [0, inf], optional)
        :param enter_editmode: Enter Edit Mode, Enter edit mode when adding this object (optional)
        :param align: Align, The alignment of the new object (optional)

    WORLD
    World -- Align the new object to the world.

    VIEW
    View -- Align the new object to the view.

    CURSOR
    3D Cursor -- Use the 3D cursor orientation for the new object.
        :param location: Location, Location for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param rotation: Rotation, Rotation for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param scale: Scale, Scale for the newly added object (array of 3 items, in [-inf, inf], optional)
        :return: Result of the operator call.
    """

def primitive_nurbs_path_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    radius: float | None = 1.0,
    enter_editmode: bool | None = False,
    align: typing.Literal["WORLD", "VIEW", "CURSOR"] | None = "WORLD",
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (
        0.0,
        0.0,
        0.0,
    ),
    rotation: collections.abc.Sequence[float] | mathutils.Euler | None = (
        0.0,
        0.0,
        0.0,
    ),
    scale: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Construct a Path

        :param radius: Radius, (in [0, inf], optional)
        :param enter_editmode: Enter Edit Mode, Enter edit mode when adding this object (optional)
        :param align: Align, The alignment of the new object (optional)

    WORLD
    World -- Align the new object to the world.

    VIEW
    View -- Align the new object to the view.

    CURSOR
    3D Cursor -- Use the 3D cursor orientation for the new object.
        :param location: Location, Location for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param rotation: Rotation, Rotation for the newly added object (array of 3 items, in [-inf, inf], optional)
        :param scale: Scale, Scale for the newly added object (array of 3 items, in [-inf, inf], optional)
        :return: Result of the operator call.
    """

def radius_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    radius: float | None = 1.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set per-point radius which is used for bevel tapering

    :param radius: Radius, (in [0, inf], optional)
    :return: Result of the operator call.
    """

def reveal(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    select: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reveal hidden control points

    :param select: Select, (optional)
    :return: Result of the operator call.
    """

def select_all(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    action: typing.Literal["TOGGLE", "SELECT", "DESELECT", "INVERT"] | None = "TOGGLE",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """(De)select all control points

        :param action: Action, Selection action to execute (optional)

    TOGGLE
    Toggle -- Toggle selection for all elements.

    SELECT
    Select -- Select all elements.

    DESELECT
    Deselect -- Deselect all elements.

    INVERT
    Invert -- Invert selection of all elements.
        :return: Result of the operator call.
    """

def select_less(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Deselect control points at the boundary of each selection region

    :return: Result of the operator call.
    """

def select_linked(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all control points linked to the current selection

    :return: Result of the operator call.
    """

def select_linked_pick(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    deselect: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all control points linked to already selected ones

    :param deselect: Deselect, Deselect linked control points rather than selecting them (optional)
    :return: Result of the operator call.
    """

def select_more(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select control points at the boundary of each selection region

    :return: Result of the operator call.
    """

def select_next(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select control points following already selected ones along the curves

    :return: Result of the operator call.
    """

def select_nth(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    skip: int | None = 1,
    nth: int | None = 1,
    offset: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Deselect every Nth point starting from the active one

    :param skip: Deselected, Number of deselected elements in the repetitive sequence (in [1, inf], optional)
    :param nth: Selected, Number of selected elements in the repetitive sequence (in [1, inf], optional)
    :param offset: Offset, Offset from the starting point (in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def select_previous(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select control points preceding already selected ones along the curves

    :return: Result of the operator call.
    """

def select_random(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    ratio: float | None = 0.5,
    seed: int | None = 0,
    action: typing.Literal["SELECT", "DESELECT"] | None = "SELECT",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Randomly select some control points

        :param ratio: Ratio, Portion of items to select randomly (in [0, 1], optional)
        :param seed: Random Seed, Seed for the random number generator (in [0, inf], optional)
        :param action: Action, Selection action to execute (optional)

    SELECT
    Select -- Select all elements.

    DESELECT
    Deselect -- Deselect all elements.
        :return: Result of the operator call.
    """

def select_row(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select a row of control points including active one. Successive use on the same point switches between U/V directions

    :return: Result of the operator call.
    """

def select_similar(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["TYPE", "RADIUS", "WEIGHT", "DIRECTION"] | None = "WEIGHT",
    compare: typing.Literal["EQUAL", "GREATER", "LESS"] | None = "EQUAL",
    threshold: float | None = 0.1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select similar curve points by property type

    :param type: Type, (optional)
    :param compare: Compare, (optional)
    :param threshold: Threshold, (in [0, inf], optional)
    :return: Result of the operator call.
    """

def separate(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Separate selected points from connected unselected points into a new object

    :return: Result of the operator call.
    """

def shade_flat(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set shading to flat

    :return: Result of the operator call.
    """

def shade_smooth(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set shading to smooth

    :return: Result of the operator call.
    """

def shortest_path_pick(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select shortest path between two selections

    :return: Result of the operator call.
    """

def smooth(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Flatten angles of selected points

    :return: Result of the operator call.
    """

def smooth_radius(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Interpolate radii of selected points

    :return: Result of the operator call.
    """

def smooth_tilt(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Interpolate tilt of selected points

    :return: Result of the operator call.
    """

def smooth_weight(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Interpolate weight of selected points

    :return: Result of the operator call.
    """

def spin(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    center: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0, 0.0),
    axis: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Extrude selected boundary row around pivot point and current view axis

    :param center: Center, Center in global view space (array of 3 items, in [-inf, inf], optional)
    :param axis: Axis, Axis in global view space (array of 3 items, in [-1, 1], optional)
    :return: Result of the operator call.
    """

def spline_type_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["POLY", "BEZIER", "NURBS"] | None = "POLY",
    use_handles: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set type of active spline

    :param type: Type, Spline type (optional)
    :param use_handles: Handles, Use handles when converting Bézier curves into polygons (optional)
    :return: Result of the operator call.
    """

def spline_weight_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    weight: float | None = 1.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set softbody goal weight for selected points

    :param weight: Weight, (in [0, 1], optional)
    :return: Result of the operator call.
    """

def split(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Split off selected points from connected unselected points

    :return: Result of the operator call.
    """

def subdivide(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    number_cuts: int | None = 1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Subdivide selected segments

    :param number_cuts: Number of Cuts, (in [1, 1000], optional)
    :return: Result of the operator call.
    """

def switch_direction(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Switch direction of selected splines

    :return: Result of the operator call.
    """

def tilt_clear(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Clear the tilt of selected control points

    :return: Result of the operator call.
    """

def vertex_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (
        0.0,
        0.0,
        0.0,
    ),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add a new control point (linked to only selected end-curve one, if any)

    :param location: Location, Location to add new vertex at (array of 3 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums
import mathutils

def align(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    axis: typing.Literal[
        "ALIGN_S", "ALIGN_T", "ALIGN_U", "ALIGN_AUTO", "ALIGN_X", "ALIGN_Y"
    ]
    | None = "ALIGN_AUTO",
    position_mode: typing.Literal["MEAN", "MIN", "MAX"] | None = "MEAN",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Aligns selected UV vertices on a line

        :param axis: Axis, Axis to align UV locations on (optional)

    ALIGN_S
    Straighten -- Align UV vertices along the line defined by the endpoints.

    ALIGN_T
    Straighten X -- Align UV vertices, moving them horizontally to the line defined by the endpoints.

    ALIGN_U
    Straighten Y -- Align UV vertices, moving them vertically to the line defined by the endpoints.

    ALIGN_AUTO
    Align Auto -- Automatically choose the direction on which there is most alignment already.

    ALIGN_X
    Align Vertically -- Align UV vertices on a vertical line.

    ALIGN_Y
    Align Horizontally -- Align UV vertices on a horizontal line.
        :param position_mode: Position Mode, Method of calculating the alignment position (optional)

    MEAN
    Mean -- Align UVs along the mean position.

    MIN
    Minimum -- Align UVs along the minimum position.

    MAX
    Maximum -- Align UVs along the maximum position.
        :return: Result of the operator call.
    """

def align_rotation(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    method: typing.Literal["AUTO", "EDGE", "GEOMETRY"] | None = "AUTO",
    axis: typing.Literal["X", "Y", "Z"] | None = "X",
    correct_aspect: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Align the UV islands rotation

        :param method: Method, Method to calculate rotation angle (optional)

    AUTO
    Auto -- Align from all edges.

    EDGE
    Edge -- Only selected edges.

    GEOMETRY
    Geometry -- Align to Geometry axis.
        :param axis: Axis, Axis to align to (optional)

    X
    X -- X axis.

    Y
    Y -- Y axis.

    Z
    Z -- Z axis.
        :param correct_aspect: Correct Aspect, Take image aspect ratio into account (optional)
        :return: Result of the operator call.
    """

def arrange_islands(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    initial_position: typing.Literal["BOUNDING_BOX", "UV_GRID", "ACTIVE_UDIM", "CURSOR"]
    | None = "BOUNDING_BOX",
    axis: typing.Literal["X", "Y"] | None = "Y",
    align: typing.Literal["MIN", "MAX", "CENTER", "NONE"] | None = "MIN",
    order: typing.Literal["LARGE_TO_SMALL", "SMALL_TO_LARGE", "Fixed"]
    | None = "LARGE_TO_SMALL",
    margin: float | None = 0.05,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Arrange selected UV islands on a line

        :param initial_position: Initial Position, Initial position to arrange islands from (optional)

    BOUNDING_BOX
    Bounding Box -- Initial alignment based on the islands bounding box.

    UV_GRID
    UV Grid -- Initial alignment based on UV Tile Grid.

    ACTIVE_UDIM
    Active UDIM -- Initial alignment based on Active UDIM.

    CURSOR
    2D Cursor -- Initial alignment based on 2D cursor.
        :param axis: Axis, Axis to arrange UV islands on (optional)

    X
    X -- Align UV islands along the X axis.

    Y
    Y -- Align UV islands along the Y axis.
        :param align: Align, Location to align islands on (optional)

    MIN
    Min -- Align the islands to the min of the island.

    MAX
    Max -- Align the islands to the max side of the island.

    CENTER
    Center -- Align the islands to the center of the largest island.

    NONE
    None -- Preserve island alignment.
        :param order: Order, Order of islands (optional)

    LARGE_TO_SMALL
    Largest to Smallest -- Sort islands from largest to smallest.

    SMALL_TO_LARGE
    Smallest to Largest -- Sort islands from smallest to largest.

    Fixed
    Fixed -- Preserve island order.
        :param margin: Margin, Space between islands (in [0, 1], optional)
        :return: Result of the operator call.
    """

def average_islands_scale(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    scale_uv: bool | None = False,
    shear: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Average the size of separate UV islands, based on their area in 3D space

    :param scale_uv: Non-Uniform, Scale U and V independently (optional)
    :param shear: Shear, Reduce shear within islands (optional)
    :return: Result of the operator call.
    """

def copy(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy selected UV vertices

    :return: Result of the operator call.
    """

def copy_mirrored_faces(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    direction: typing.Literal["POSITIVE", "NEGATIVE"] | None = "POSITIVE",
    precision: int | None = 3,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy mirror UV coordinates on the X axis based on a mirrored mesh

    :param direction: Axis Direction, (optional)
    :param precision: Precision, Tolerance for finding vertex duplicates (in [1, 16], optional)
    :return: Result of the operator call.
    """

def cube_project(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    cube_size: float | None = 1.0,
    correct_aspect: bool | None = True,
    clip_to_bounds: bool | None = False,
    scale_to_bounds: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Project the UV vertices of the mesh over the six faces of a cube

    :param cube_size: Cube Size, Size of the cube to project on (in [0, inf], optional)
    :param correct_aspect: Correct Aspect, Map UVs taking aspect ratio of the image associated with the material into account (optional)
    :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping (optional)
    :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping (optional)
    :return: Result of the operator call.
    """

def cursor_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set 2D cursor location

    :param location: Location, Cursor location in normalized (0.0 to 1.0) coordinates (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def custom_region_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    xmin: int | None = 0,
    xmax: int | None = 0,
    ymin: int | None = 0,
    ymax: int | None = 0,
    wait_for_input: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set the boundaries of the user region

    :param xmin: X Min, (in [-inf, inf], optional)
    :param xmax: X Max, (in [-inf, inf], optional)
    :param ymin: Y Min, (in [-inf, inf], optional)
    :param ymax: Y Max, (in [-inf, inf], optional)
    :param wait_for_input: Wait for Input, (optional)
    :return: Result of the operator call.
    """

def cylinder_project(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    direction: typing.Literal["VIEW_ON_EQUATOR", "VIEW_ON_POLES", "ALIGN_TO_OBJECT"]
    | None = "VIEW_ON_EQUATOR",
    align: typing.Literal["POLAR_ZX", "POLAR_ZY"] | None = "POLAR_ZX",
    pole: typing.Literal["PINCH", "FAN"] | None = "PINCH",
    seam: bool | None = False,
    radius: float | None = 1.0,
    correct_aspect: bool | None = True,
    clip_to_bounds: bool | None = False,
    scale_to_bounds: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Project the UV vertices of the mesh over the curved wall of a cylinder

        :param direction: Direction, Direction of the sphere or cylinder (optional)

    VIEW_ON_EQUATOR
    View on Equator -- 3D view is on the equator.

    VIEW_ON_POLES
    View on Poles -- 3D view is on the poles.

    ALIGN_TO_OBJECT
    Align to Object -- Align according to object transform.
        :param align: Align, How to determine rotation around the pole (optional)

    POLAR_ZX
    Polar ZX -- Polar 0 is X.

    POLAR_ZY
    Polar ZY -- Polar 0 is Y.
        :param pole: Pole, How to handle faces at the poles (optional)

    PINCH
    Pinch -- UVs are pinched at the poles.

    FAN
    Fan -- UVs are fanned at the poles.
        :param seam: Preserve Seams, Separate projections by islands isolated by seams (optional)
        :param radius: Radius, Radius of the sphere or cylinder (in [0, inf], optional)
        :param correct_aspect: Correct Aspect, Map UVs taking aspect ratio of the image associated with the material into account (optional)
        :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping (optional)
        :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping (optional)
        :return: Result of the operator call.
    """

def export_layout(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
    export_all: bool | None = False,
    export_tiles: typing.Literal["NONE", "UDIM", "UV"] | None = "NONE",
    modified: bool | None = False,
    mode: typing.Literal["SVG", "EPS", "PNG"] | None = "PNG",
    size: collections.abc.Sequence[int] | None = (1024, 1024),
    opacity: float | None = 0.25,
    check_existing: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Export UV layout to file

        :param filepath: filepath, (optional, never None)
        :param export_all: All UVs, Export all UVs in this mesh (not just visible ones) (optional)
        :param export_tiles: Export Tiles, Choose whether to export only the [0, 1] range, or all UV tiles (optional)

    NONE
    None -- Export only UVs in the [0, 1] range.

    UDIM
    UDIM -- Export tiles in the UDIM numbering scheme: 1001 + u_tile + 10*v_tile.

    UV
    UVTILE -- Export tiles in the UVTILE numbering scheme: u(u_tile + 1)_v(v_tile + 1).
        :param modified: Modified, Exports UVs from the modified mesh (optional)
        :param mode: Format, File format to export the UV layout to (optional)

    SVG
    Scalable Vector Graphic (.svg) -- Export the UV layout to a vector SVG file.

    EPS
    Encapsulated PostScript (.eps) -- Export the UV layout to a vector EPS file.

    PNG
    PNG Image (.png) -- Export the UV layout to a bitmap image.
        :param size: Size, Dimensions of the exported file (array of 2 items, in [8, 32768], optional)
        :param opacity: Fill Opacity, Set amount of opacity for exported UV layout (in [0, 1], optional)
        :param check_existing: check_existing, (optional)
        :return: Result of the operator call.
    """

def follow_active_quads(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mode: typing.Literal["EVEN", "LENGTH", "LENGTH_AVERAGE"] | None = "LENGTH_AVERAGE",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Follow UVs from active quads along continuous face loops

        :param mode: Edge Length Mode, Method to space UV edge loops (optional)

    EVEN
    Even -- Space all UVs evenly.

    LENGTH
    Length -- Average space UVs edge length of each loop.

    LENGTH_AVERAGE
    Length Average -- Average space UVs edge length of each loop.
        :return: Result of the operator call.
    """

def hide(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    unselected: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Hide (un)selected UV vertices

    :param unselected: Unselected, Hide unselected rather than selected (optional)
    :return: Result of the operator call.
    """

def lightmap_pack(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    PREF_CONTEXT: typing.Literal["SEL_FACES", "ALL_FACES"] | None = "SEL_FACES",
    PREF_PACK_IN_ONE: bool | None = True,
    PREF_NEW_UVLAYER: bool | None = False,
    PREF_BOX_DIV: int | None = 12,
    PREF_MARGIN_DIV: float | None = 0.1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Pack each faces UVs into the UV bounds

        :param PREF_CONTEXT: Selection, (optional)

    SEL_FACES
    Selected Faces -- Pack only selected faces.

    ALL_FACES
    All Faces -- Pack all faces in the mesh.
        :param PREF_PACK_IN_ONE: Share Texture Space, Objects share texture space, map all objects into a single UV map (optional)
        :param PREF_NEW_UVLAYER: New UV Map, Create a new UV map for every mesh packed (optional)
        :param PREF_BOX_DIV: Pack Quality, Quality of the packing. Higher values will be slower but waste less space (in [1, 48], optional)
        :param PREF_MARGIN_DIV: Margin, Size of the margin as a division of the UV (in [0.001, 1], optional)
        :return: Result of the operator call.
    """

def mark_seam(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    clear: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Mark selected UV edges as seams

    :param clear: Clear Seams, Clear instead of marking seams (optional)
    :return: Result of the operator call.
    """

def minimize_stretch(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    fill_holes: bool | None = True,
    blend: float | None = 0.0,
    iterations: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reduce UV stretching by relaxing angles

    :param fill_holes: Fill Holes, Virtually fill holes in mesh before unwrapping, to better avoid overlaps and preserve symmetry (optional)
    :param blend: Blend, Blend factor between stretch minimized and original (in [0, 1], optional)
    :param iterations: Iterations, Number of iterations to run, 0 is unlimited when run interactively (in [0, inf], optional)
    :return: Result of the operator call.
    """

def move_on_axis(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal["DYNAMIC", "PIXEL", "UDIM"] | None = "UDIM",
    axis: typing.Literal["X", "Y"] | None = "X",
    distance: int | None = 1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Move UVs on an axis

        :param type: Type, Move Type (optional)

    DYNAMIC
    Dynamic -- Move by dynamic grid.

    PIXEL
    Pixel -- Move by pixel.

    UDIM
    UDIM -- Move by UDIM.
        :param axis: Axis, Axis to move UVs on (optional)

    X
    X axis -- Move vertices on the X axis.

    Y
    Y axis -- Move vertices on the Y axis.
        :param distance: Distance, Distance to move UVs (in [-inf, inf], optional)
        :return: Result of the operator call.
    """

def pack_islands(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    udim_source: typing.Literal[
        "CLOSEST_UDIM", "ACTIVE_UDIM", "ORIGINAL_AABB", "CUSTOM_REGION"
    ]
    | None = "CLOSEST_UDIM",
    rotate: bool | None = True,
    rotate_method: typing.Literal[
        "ANY", "CARDINAL", "AXIS_ALIGNED", "AXIS_ALIGNED_X", "AXIS_ALIGNED_Y"
    ]
    | None = "ANY",
    scale: bool | None = True,
    merge_overlap: bool | None = False,
    margin_method: typing.Literal["SCALED", "ADD", "FRACTION"] | None = "SCALED",
    margin: float | None = 0.001,
    pin: bool | None = False,
    pin_method: typing.Literal["SCALE", "ROTATION", "ROTATION_SCALE", "LOCKED"]
    | None = "LOCKED",
    shape_method: typing.Literal["CONCAVE", "CONVEX", "AABB"] | None = "CONCAVE",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Transform all islands so that they fill up the UV/UDIM space as much as possible

        :param udim_source: Pack to, (optional)

    CLOSEST_UDIM
    Closest UDIM -- Pack islands to closest UDIM.

    ACTIVE_UDIM
    Active UDIM -- Pack islands to active UDIM image tile or UDIM grid tile where 2D cursor is located.

    ORIGINAL_AABB
    Original bounding box -- Pack to starting bounding box of islands.

    CUSTOM_REGION
    Custom Region -- Pack islands to custom region.
        :param rotate: Rotate, Rotate islands to improve layout (optional)
        :param rotate_method: Rotation Method, (optional)

    ANY
    Any -- Any angle is allowed for rotation.

    CARDINAL
    Cardinal -- Only 90 degree rotations are allowed.

    AXIS_ALIGNED
    Axis-aligned -- Rotated to a minimal rectangle, either vertical or horizontal.

    AXIS_ALIGNED_X
    Axis-aligned (Horizontal) -- Rotate islands to be aligned horizontally.

    AXIS_ALIGNED_Y
    Axis-aligned (Vertical) -- Rotate islands to be aligned vertically.
        :param scale: Scale, Scale islands to fill unit square (optional)
        :param merge_overlap: Merge Overlapping, Overlapping islands stick together (optional)
        :param margin_method: Margin Method, (optional)

    SCALED
    Scaled -- Use scale of existing UVs to multiply margin.

    ADD
    Add -- Just add the margin, ignoring any UV scale.

    FRACTION
    Fraction -- Specify a precise fraction of final UV output.
        :param margin: Margin, Space between islands (in [0, 1], optional)
        :param pin: Lock Pinned Islands, Constrain islands containing any pinned UVs (optional)
        :param pin_method: Pin Method, (optional)

    SCALE
    Scale -- Pinned islands wont rescale.

    ROTATION
    Rotation -- Pinned islands wont rotate.

    ROTATION_SCALE
    Rotation and Scale -- Pinned islands will translate only.

    LOCKED
    All -- Pinned islands are locked in place.
        :param shape_method: Shape Method, (optional)

    CONCAVE
    Exact Shape (Concave) -- Uses exact geometry.

    CONVEX
    Boundary Shape (Convex) -- Uses convex hull.

    AABB
    Bounding Box -- Uses bounding boxes.
        :return: Result of the operator call.
    """

def paste(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Paste selected UV vertices

    :return: Result of the operator call.
    """

def pin(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    clear: bool | None = False,
    invert: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set/clear selected UV vertices as anchored between multiple unwrap operations

    :param clear: Clear, Clear pinning for the selection instead of setting it (optional)
    :param invert: Invert, Invert pinning for the selection instead of setting it (optional)
    :return: Result of the operator call.
    """

def project_from_view(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    orthographic: bool | None = False,
    camera_bounds: bool | None = True,
    correct_aspect: bool | None = True,
    clip_to_bounds: bool | None = False,
    scale_to_bounds: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Project the UV vertices of the mesh as seen in current 3D view

    :param orthographic: Orthographic, Use orthographic projection (optional)
    :param camera_bounds: Camera Bounds, Map UVs to the camera region taking resolution and aspect into account (optional)
    :param correct_aspect: Correct Aspect, Map UVs taking aspect ratio of the image associated with the material into account (optional)
    :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping (optional)
    :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping (optional)
    :return: Result of the operator call.
    """

def randomize_uv_transform(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    random_seed: int | None = 0,
    use_loc: bool | None = True,
    loc: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
    use_rot: bool | None = True,
    rot: float | None = 0.0,
    use_scale: bool | None = True,
    scale_even: bool | None = False,
    scale: collections.abc.Sequence[float] | None = (1.0, 1.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Randomize the UV islands location, rotation, and scale

    :param random_seed: Random Seed, Seed value for the random generator (in [0, 10000], optional)
    :param use_loc: Randomize Location, Randomize the location values (optional)
    :param loc: Location, Maximum distance the objects can spread over each axis (array of 2 items, in [-100, 100], optional)
    :param use_rot: Randomize Rotation, Randomize the rotation value (optional)
    :param rot: Rotation, Maximum rotation (in [-6.28319, 6.28319], optional)
    :param use_scale: Randomize Scale, Randomize the scale values (optional)
    :param scale_even: Scale Even, Use the same scale value for both axes (optional)
    :param scale: Scale, Maximum scale randomization over each axis (array of 2 items, in [-100, 100], optional)
    :return: Result of the operator call.
    """

def remove_doubles(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    threshold: float | None = 0.02,
    use_unselected: bool | None = False,
    use_shared_vertex: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Selected UV vertices that are within a radius of each other are welded together

    :param threshold: Merge Distance, Maximum distance between welded vertices (in [0, 10], optional)
    :param use_unselected: Unselected, Merge selected to other unselected vertices (optional)
    :param use_shared_vertex: Shared Vertex, Weld UVs based on shared vertices (optional)
    :return: Result of the operator call.
    """

def reset(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reset UV projection

    :return: Result of the operator call.
    """

def reveal(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    select: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reveal all hidden UV vertices

    :param select: Select, (optional)
    :return: Result of the operator call.
    """

def rip(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mirror: bool | None = False,
    release_confirm: bool | None = False,
    use_accurate: bool | None = False,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Rip selected vertices or a selected region

    :param mirror: Mirror Editing, (optional)
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button (optional)
    :param use_accurate: Accurate, Use accurate transformation (optional)
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def rip_move(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    UV_OT_rip: dict[str, typing.Any] | None = {},
    TRANSFORM_OT_translate: dict[str, typing.Any] | None = {},
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Unstitch UVs and move the result

    :param UV_OT_rip: UV Rip, Rip selected vertices or a selected region (optional, `bpy.ops.uv.rip` keyword arguments)
    :param TRANSFORM_OT_translate: Move, Move selected items (optional, `bpy.ops.transform.translate` keyword arguments)
    :return: Result of the operator call.
    """

def seams_from_islands(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mark_seams: bool | None = True,
    mark_sharp: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set mesh seams according to island setup in the UV editor

    :param mark_seams: Mark Seams, Mark boundary edges as seams (optional)
    :param mark_sharp: Mark Sharp, Mark boundary edges as sharp (optional)
    :return: Result of the operator call.
    """

def select(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
    deselect: bool | None = False,
    toggle: bool | None = False,
    deselect_all: bool | None = False,
    select_passthrough: bool | None = False,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select UV vertices

    :param extend: Extend, Extend selection instead of deselecting everything first (optional)
    :param deselect: Deselect, Remove from selection (optional)
    :param toggle: Toggle Selection, Toggle the selection (optional)
    :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor (optional)
    :param select_passthrough: Only Select Unselected, Ignore the select action when the element is already selected (optional)
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def select_all(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    action: typing.Literal["TOGGLE", "SELECT", "DESELECT", "INVERT"] | None = "TOGGLE",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Change selection of all UV vertices

        :param action: Action, Selection action to execute (optional)

    TOGGLE
    Toggle -- Toggle selection for all elements.

    SELECT
    Select -- Select all elements.

    DESELECT
    Deselect -- Deselect all elements.

    INVERT
    Invert -- Invert selection of all elements.
        :return: Result of the operator call.
    """

def select_box(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    pinned: bool | None = False,
    xmin: int | None = 0,
    xmax: int | None = 0,
    ymin: int | None = 0,
    ymax: int | None = 0,
    wait_for_input: bool | None = True,
    mode: typing.Literal["SET", "ADD", "SUB"] | None = "SET",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select UV vertices using box selection

        :param pinned: Pinned, Border select pinned UVs only (optional)
        :param xmin: X Min, (in [-inf, inf], optional)
        :param xmax: X Max, (in [-inf, inf], optional)
        :param ymin: Y Min, (in [-inf, inf], optional)
        :param ymax: Y Max, (in [-inf, inf], optional)
        :param wait_for_input: Wait for Input, (optional)
        :param mode: Mode, (optional)

    SET
    Set -- Set a new selection.

    ADD
    Extend -- Extend existing selection.

    SUB
    Subtract -- Subtract existing selection.
        :return: Result of the operator call.
    """

def select_circle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    x: int | None = 0,
    y: int | None = 0,
    radius: int | None = 25,
    wait_for_input: bool | None = True,
    mode: typing.Literal["SET", "ADD", "SUB"] | None = "SET",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select UV vertices using circle selection

        :param x: X, (in [-inf, inf], optional)
        :param y: Y, (in [-inf, inf], optional)
        :param radius: Radius, (in [1, inf], optional)
        :param wait_for_input: Wait for Input, (optional)
        :param mode: Mode, (optional)

    SET
    Set -- Set a new selection.

    ADD
    Extend -- Extend existing selection.

    SUB
    Subtract -- Subtract existing selection.
        :return: Result of the operator call.
    """

def select_edge_ring(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select an edge ring of connected UV vertices

    :param extend: Extend, Extend selection rather than clearing the existing selection (optional)
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def select_lasso(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    path=None,
    use_smooth_stroke: bool | None = False,
    smooth_stroke_factor: float | None = 0.75,
    smooth_stroke_radius: int | None = 35,
    mode: typing.Literal["SET", "ADD", "SUB"] | None = "SET",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select UVs using lasso selection

        :param path: Path, (optional)
        :param use_smooth_stroke: Stabilize Stroke, Selection lags behind mouse and follows a smoother path (optional)
        :param smooth_stroke_factor: Smooth Stroke Factor, Higher values give a smoother stroke (in [0.5, 0.99], optional)
        :param smooth_stroke_radius: Smooth Stroke Radius, Minimum distance from last point before selection continues (in [10, 200], optional)
        :param mode: Mode, (optional)

    SET
    Set -- Set a new selection.

    ADD
    Extend -- Extend existing selection.

    SUB
    Subtract -- Subtract existing selection.
        :return: Result of the operator call.
    """

def select_less(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Deselect UV vertices at the boundary of each selection region

    :return: Result of the operator call.
    """

def select_linked(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all UV vertices linked to the active UV map

    :return: Result of the operator call.
    """

def select_linked_pick(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
    deselect: bool | None = False,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all UV vertices linked under the mouse

    :param extend: Extend, Extend selection rather than clearing the existing selection (optional)
    :param deselect: Deselect, Deselect linked UV vertices rather than selecting them (optional)
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def select_loop(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select a loop of connected UV vertices

    :param extend: Extend, Extend selection rather than clearing the existing selection (optional)
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def select_mode(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: Literal[bpy.stub_internal.rna_enums.MeshSelectModeUvItems] | None = "VERTEX",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Change UV selection mode

    :param type: Type, (optional)
    :return: Result of the operator call.
    """

def select_more(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select more UV vertices connected to initial selection

    :return: Result of the operator call.
    """

def select_overlap(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all UV faces which overlap each other

    :param extend: Extend, Extend selection rather than clearing the existing selection (optional)
    :return: Result of the operator call.
    """

def select_pinned(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all pinned UV vertices

    :return: Result of the operator call.
    """

def select_similar(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal[
        "PIN",
        "LENGTH",
        "LENGTH_3D",
        "AREA",
        "AREA_3D",
        "MATERIAL",
        "OBJECT",
        "SIDES",
        "WINDING",
        "FACE",
    ]
    | None = "PIN",
    compare: typing.Literal["EQUAL", "GREATER", "LESS"] | None = "EQUAL",
    threshold: float | None = 0.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select similar UVs by property types

        :param type: Type, (optional)

    PIN
    Pinned.

    LENGTH
    Length -- Edge length in UV space.

    LENGTH_3D
    Length 3D -- Length of edge in 3D space.

    AREA
    Area -- Face area in UV space.

    AREA_3D
    Area 3D -- Area of face in 3D space.

    MATERIAL
    Material.

    OBJECT
    Object.

    SIDES
    Polygon Sides.

    WINDING
    Winding -- Face direction defined by clockwise or anti-clockwise winding (facing up or facing down).

    FACE
    Amount of Faces in Island.
        :param compare: Compare, (optional)
        :param threshold: Threshold, (in [0, 1], optional)
        :return: Result of the operator call.
    """

def select_split(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select only entirely selected faces

    :return: Result of the operator call.
    """

def select_tile(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    extend: bool | None = False,
    tile: collections.abc.Sequence[int] | None = (0, 0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select UVs in specified tile

    :param extend: Extend, Extend the selection (optional)
    :param tile: Tile, Tile location to select UVs (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def shortest_path_pick(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    use_face_step: bool | None = False,
    use_topology_distance: bool | None = False,
    use_fill: bool | None = False,
    skip: int | None = 0,
    nth: int | None = 1,
    offset: int | None = 0,
    object_index: int | None = -1,
    index: int | None = -1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select shortest path between two selections

    :param use_face_step: Face Stepping, Traverse connected faces (includes diagonals and edge-rings) (optional)
    :param use_topology_distance: Topology Distance, Find the minimum number of steps, ignoring spatial distance (optional)
    :param use_fill: Fill Region, Select all paths between the source/destination elements (optional)
    :param skip: Deselected, Number of deselected elements in the repetitive sequence (in [0, inf], optional)
    :param nth: Selected, Number of selected elements in the repetitive sequence (in [1, inf], optional)
    :param offset: Offset, Offset from the starting point (in [-inf, inf], optional)
    :param object_index: (in [-1, inf], optional)
    :param index: (in [-1, inf], optional)
    :return: Result of the operator call.
    """

def shortest_path_select(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    use_face_step: bool | None = False,
    use_topology_distance: bool | None = False,
    use_fill: bool | None = False,
    skip: int | None = 0,
    nth: int | None = 1,
    offset: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select shortest path between two vertices/edges/faces

    :param use_face_step: Face Stepping, Traverse connected faces (includes diagonals and edge-rings) (optional)
    :param use_topology_distance: Topology Distance, Find the minimum number of steps, ignoring spatial distance (optional)
    :param use_fill: Fill Region, Select all paths between the source/destination elements (optional)
    :param skip: Deselected, Number of deselected elements in the repetitive sequence (in [0, inf], optional)
    :param nth: Selected, Number of selected elements in the repetitive sequence (in [1, inf], optional)
    :param offset: Offset, Offset from the starting point (in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def smart_project(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    angle_limit: float | None = 1.15192,
    margin_method: typing.Literal["SCALED", "ADD", "FRACTION"] | None = "SCALED",
    rotate_method: typing.Literal["AXIS_ALIGNED", "AXIS_ALIGNED_X", "AXIS_ALIGNED_Y"]
    | None = "AXIS_ALIGNED_Y",
    island_margin: float | None = 0.0,
    area_weight: float | None = 0.0,
    correct_aspect: bool | None = True,
    scale_to_bounds: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Projection unwraps the selected faces of mesh objects

        :param angle_limit: Angle Limit, Lower for more projection groups, higher for less distortion (in [0, 1.5708], optional)
        :param margin_method: Margin Method, (optional)

    SCALED
    Scaled -- Use scale of existing UVs to multiply margin.

    ADD
    Add -- Just add the margin, ignoring any UV scale.

    FRACTION
    Fraction -- Specify a precise fraction of final UV output.
        :param rotate_method: Rotation Method, (optional)

    AXIS_ALIGNED
    Axis-aligned -- Rotated to a minimal rectangle, either vertical or horizontal.

    AXIS_ALIGNED_X
    Axis-aligned (Horizontal) -- Rotate islands to be aligned horizontally.

    AXIS_ALIGNED_Y
    Axis-aligned (Vertical) -- Rotate islands to be aligned vertically.
        :param island_margin: Island Margin, Margin to reduce bleed from adjacent islands (in [0, 1], optional)
        :param area_weight: Area Weight, Weight projections vector by faces with larger areas (in [0, 1], optional)
        :param correct_aspect: Correct Aspect, Map UVs taking aspect ratio of the image associated with the material into account (optional)
        :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping (optional)
        :return: Result of the operator call.
    """

def snap_cursor(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    target: typing.Literal["PIXELS", "SELECTED", "ORIGIN"] | None = "PIXELS",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Snap cursor to target type

    :param target: Target, Target to snap the selected UVs to (optional)
    :return: Result of the operator call.
    """

def snap_selected(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    target: typing.Literal["PIXELS", "CURSOR", "CURSOR_OFFSET", "ADJACENT_UNSELECTED"]
    | None = "PIXELS",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Snap selected UV vertices to target type

    :param target: Target, Target to snap the selected UVs to (optional)
    :return: Result of the operator call.
    """

def sphere_project(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    direction: typing.Literal["VIEW_ON_EQUATOR", "VIEW_ON_POLES", "ALIGN_TO_OBJECT"]
    | None = "VIEW_ON_EQUATOR",
    align: typing.Literal["POLAR_ZX", "POLAR_ZY"] | None = "POLAR_ZX",
    pole: typing.Literal["PINCH", "FAN"] | None = "PINCH",
    seam: bool | None = False,
    correct_aspect: bool | None = True,
    clip_to_bounds: bool | None = False,
    scale_to_bounds: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Project the UV vertices of the mesh over the curved surface of a sphere

        :param direction: Direction, Direction of the sphere or cylinder (optional)

    VIEW_ON_EQUATOR
    View on Equator -- 3D view is on the equator.

    VIEW_ON_POLES
    View on Poles -- 3D view is on the poles.

    ALIGN_TO_OBJECT
    Align to Object -- Align according to object transform.
        :param align: Align, How to determine rotation around the pole (optional)

    POLAR_ZX
    Polar ZX -- Polar 0 is X.

    POLAR_ZY
    Polar ZY -- Polar 0 is Y.
        :param pole: Pole, How to handle faces at the poles (optional)

    PINCH
    Pinch -- UVs are pinched at the poles.

    FAN
    Fan -- UVs are fanned at the poles.
        :param seam: Preserve Seams, Separate projections by islands isolated by seams (optional)
        :param correct_aspect: Correct Aspect, Map UVs taking aspect ratio of the image associated with the material into account (optional)
        :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping (optional)
        :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping (optional)
        :return: Result of the operator call.
    """

def stitch(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    use_limit: bool | None = False,
    snap_islands: bool | None = True,
    limit: float | None = 0.01,
    static_island: int | None = 0,
    active_object_index: int | None = 0,
    midpoint_snap: bool | None = False,
    clear_seams: bool | None = True,
    mode: typing.Literal["VERTEX", "EDGE"] | None = "VERTEX",
    stored_mode: typing.Literal["VERTEX", "EDGE"] | None = "VERTEX",
    selection=None,
    objects_selection_count: collections.abc.Sequence[int] | None = (0, 0, 0, 0, 0, 0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Stitch selected UV vertices by proximity

    :param use_limit: Use Limit, Stitch UVs within a specified limit distance (optional)
    :param snap_islands: Snap Islands, Snap islands together (on edge stitch mode, rotates the islands too) (optional)
    :param limit: Limit, Limit distance in normalized coordinates (in [0, inf], optional)
    :param static_island: Static Island, Island that stays in place when stitching islands (in [0, inf], optional)
    :param active_object_index: Active Object, Index of the active object (in [0, inf], optional)
    :param midpoint_snap: Snap at Midpoint, UVs are stitched at midpoint instead of at static island (optional)
    :param clear_seams: Clear Seams, Clear seams of stitched edges (optional)
    :param mode: Operation Mode, Use vertex or edge stitching (optional)
    :param stored_mode: Stored Operation Mode, Use vertex or edge stitching (optional)
    :param selection: Selection, (optional)
    :param objects_selection_count: Objects Selection Count, (array of 6 items, in [0, inf], optional)
    :return: Result of the operator call.
    """

def unwrap(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    method: typing.Literal["ANGLE_BASED", "CONFORMAL", "MINIMUM_STRETCH"]
    | None = "CONFORMAL",
    fill_holes: bool | None = False,
    correct_aspect: bool | None = True,
    use_subsurf_data: bool | None = False,
    margin_method: typing.Literal["SCALED", "ADD", "FRACTION"] | None = "SCALED",
    margin: float | None = 0.001,
    no_flip: bool | None = False,
    iterations: int | None = 10,
    use_weights: bool | None = False,
    weight_group: str | None = "uv_importance",
    weight_factor: float | None = 1.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Unwrap the mesh of the object being edited

        :param method: Method, Unwrapping method (Angle Based usually gives better results than Conformal, while being somewhat slower) (optional)
        :param fill_holes: Fill Holes, Virtually fill holes in mesh before unwrapping, to better avoid overlaps and preserve symmetry (optional)
        :param correct_aspect: Correct Aspect, Map UVs taking aspect ratio of the image associated with the material into account (optional)
        :param use_subsurf_data: Use Subdivision Surface, Map UVs taking vertex position after Subdivision Surface modifier has been applied (optional)
        :param margin_method: Margin Method, (optional)

    SCALED
    Scaled -- Use scale of existing UVs to multiply margin.

    ADD
    Add -- Just add the margin, ignoring any UV scale.

    FRACTION
    Fraction -- Specify a precise fraction of final UV output.
        :param margin: Margin, Space between islands (in [0, 1], optional)
        :param no_flip: No Flip, Prevent flipping UVs, flipping may lower distortion depending on the position of pins (optional)
        :param iterations: Iterations, Number of iterations when "Minimum Stretch" method is used (in [0, 10000], optional)
        :param use_weights: Importance Weights, Whether to take into account per-vertex importance weights (optional)
        :param weight_group: Weight Group, Vertex group name for importance weights (modulating the deform) (optional, never None)
        :param weight_factor: Weight Factor, How much influence the weightmap has for weighted parameterization, 0 being no influence (in [-10000, 10000], optional)
        :return: Result of the operator call.
    """

def weld(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Weld selected UV vertices together

    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def case_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    case: typing.Literal["LOWER", "UPPER"] | None = "LOWER",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set font case

    :param case: Case, Lower or upper case (optional)
    :return: Result of the operator call.
    """

def case_toggle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Toggle font case

    :return: Result of the operator call.
    """

def change_character(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    delta: int | None = 1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Change font character code

    :param delta: Delta, Number to increase or decrease character code with (in [-255, 255], optional)
    :return: Result of the operator call.
    """

def change_spacing(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    delta: float | None = 1.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Change font spacing

    :param delta: Delta, Amount to decrease or increase character spacing with (in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def delete(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal[
        "NEXT_CHARACTER",
        "PREVIOUS_CHARACTER",
        "NEXT_WORD",
        "PREVIOUS_WORD",
        "SELECTION",
        "NEXT_OR_SELECTION",
        "PREVIOUS_OR_SELECTION",
    ]
    | None = "PREVIOUS_CHARACTER",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete text by cursor position

    :param type: Type, Which part of the text to delete (optional)
    :return: Result of the operator call.
    """

def line_break(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Insert line break at cursor position

    :return: Result of the operator call.
    """

def move(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal[
        "LINE_BEGIN",
        "LINE_END",
        "TEXT_BEGIN",
        "TEXT_END",
        "PREVIOUS_CHARACTER",
        "NEXT_CHARACTER",
        "PREVIOUS_WORD",
        "NEXT_WORD",
        "PREVIOUS_LINE",
        "NEXT_LINE",
        "PREVIOUS_PAGE",
        "NEXT_PAGE",
    ]
    | None = "LINE_BEGIN",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Move cursor to position type

    :param type: Type, Where to move cursor to (optional)
    :return: Result of the operator call.
    """

def move_select(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    type: typing.Literal[
        "LINE_BEGIN",
        "LINE_END",
        "TEXT_BEGIN",
        "TEXT_END",
        "PREVIOUS_CHARACTER",
        "NEXT_CHARACTER",
        "PREVIOUS_WORD",
        "NEXT_WORD",
        "PREVIOUS_LINE",
        "NEXT_LINE",
        "PREVIOUS_PAGE",
        "NEXT_PAGE",
    ]
    | None = "LINE_BEGIN",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Move the cursor while selecting

    :param type: Type, Where to move cursor to, to make a selection (optional)
    :return: Result of the operator call.
    """

def open(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
    hide_props_region: bool | None = True,
    check_existing: bool | None = False,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = False,
    filter_movie: bool | None = False,
    filter_python: bool | None = False,
    filter_font: bool | None = True,
    filter_sound: bool | None = False,
    filter_text: bool | None = False,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    relative_path: bool | None = True,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "THUMBNAIL",
    sort_method: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Load a new font from a file

        :param filepath: File Path, Path to file (optional, never None)
        :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings (optional)
        :param check_existing: Check Existing, Check and warn on overwriting existing files (optional)
        :param filter_blender: Filter .blend files, (optional)
        :param filter_backup: Filter backup .blend files, (optional)
        :param filter_image: Filter image files, (optional)
        :param filter_movie: Filter movie files, (optional)
        :param filter_python: Filter Python files, (optional)
        :param filter_font: Filter font files, (optional)
        :param filter_sound: Filter sound files, (optional)
        :param filter_text: Filter text files, (optional)
        :param filter_archive: Filter archive files, (optional)
        :param filter_btx: Filter btx files, (optional)
        :param filter_alembic: Filter Alembic files, (optional)
        :param filter_usd: Filter USD files, (optional)
        :param filter_obj: Filter OBJ files, (optional)
        :param filter_volume: Filter OpenVDB volume files, (optional)
        :param filter_folder: Filter folders, (optional)
        :param filter_blenlib: Filter Blender IDs, (optional)
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file (in [1, 9], optional)
        :param relative_path: Relative Path, Select the file relative to the blend file (optional)
        :param display_type: Display Type, (optional)

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :param sort_method: File sorting mode, (optional)
        :return: Result of the operator call.
    """

def select_all(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select all text

    :return: Result of the operator call.
    """

def select_word(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select word under cursor

    :return: Result of the operator call.
    """

def selection_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set cursor selection

    :return: Result of the operator call.
    """

def style_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    style: typing.Literal["BOLD", "ITALIC", "UNDERLINE", "SMALL_CAPS"] | None = "BOLD",
    clear: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set font style

    :param style: Style, Style to set selection to (optional)
    :param clear: Clear, Clear style rather than setting it (optional)
    :return: Result of the operator call.
    """

def style_toggle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    style: typing.Literal["BOLD", "ITALIC", "UNDERLINE", "SMALL_CAPS"] | None = "BOLD",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Toggle font style

    :param style: Style, Style to set selection to (optional)
    :return: Result of the operator call.
    """

def text_copy(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy selected text to clipboard

    :return: Result of the operator call.
    """

def text_cut(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Cut selected text to clipboard

    :return: Result of the operator call.
    """

def text_insert(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    text: str | None = "",
    accent: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Insert text at cursor position

    :param text: Text, Text to insert at the cursor position (optional, never None)
    :param accent: Accent Mode, Next typed character will strike through previous, for special character input (optional)
    :return: Result of the operator call.
    """

def text_insert_unicode(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Insert Unicode Character

    :return: Result of the operator call.
    """

def text_paste(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    selection: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Paste text from clipboard

    :param selection: Selection, Paste text selected elsewhere rather than copied (X11/Wayland only) (optional)
    :return: Result of the operator call.
    """

def text_paste_from_file(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
    hide_props_region: bool | None = True,
    check_existing: bool | None = False,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = False,
    filter_movie: bool | None = False,
    filter_python: bool | None = False,
    filter_font: bool | None = False,
    filter_sound: bool | None = False,
    filter_text: bool | None = True,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "DEFAULT",
    sort_method: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Paste contents from file

        :param filepath: File Path, Path to file (optional, never None)
        :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings (optional)
        :param check_existing: Check Existing, Check and warn on overwriting existing files (optional)
        :param filter_blender: Filter .blend files, (optional)
        :param filter_backup: Filter backup .blend files, (optional)
        :param filter_image: Filter image files, (optional)
        :param filter_movie: Filter movie files, (optional)
        :param filter_python: Filter Python files, (optional)
        :param filter_font: Filter font files, (optional)
        :param filter_sound: Filter sound files, (optional)
        :param filter_text: Filter text files, (optional)
        :param filter_archive: Filter archive files, (optional)
        :param filter_btx: Filter btx files, (optional)
        :param filter_alembic: Filter Alembic files, (optional)
        :param filter_usd: Filter USD files, (optional)
        :param filter_obj: Filter OBJ files, (optional)
        :param filter_volume: Filter OpenVDB volume files, (optional)
        :param filter_folder: Filter folders, (optional)
        :param filter_blenlib: Filter Blender IDs, (optional)
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file (in [1, 9], optional)
        :param display_type: Display Type, (optional)

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :param sort_method: File sorting mode, (optional)
        :return: Result of the operator call.
    """

def textbox_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add a new text box

    :return: Result of the operator call.
    """

def textbox_remove(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    index: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove the text box

    :param index: Index, The current text box (in [0, inf], optional)
    :return: Result of the operator call.
    """

def unlink(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Unlink active font data-block

    :return: Result of the operator call.
    """
